diff --git a/core/includes/update.inc b/core/includes/update.inc
index e5c62d8..fb6f450 100644
--- a/core/includes/update.inc
+++ b/core/includes/update.inc
@@ -321,9 +321,11 @@ function update_module_enable(array $modules) {
  * will be displayed at all.
  *
  * If it fails for whatever reason, it should throw an instance of
- * DrupalUpdateException with an appropriate error message, for example:
+ * Drupal\Core\Utility\UpdateException with an appropriate error message, for
+ * example:
  * @code
- * throw new DrupalUpdateException(t('Description of what went wrong'));
+ * use Drupal\Core\Utility\UpdateException;
+ * throw new UpdateException(t('Description of what went wrong'));
  * @endcode
  *
  * If an exception is thrown, the current update and all updates that depend on
@@ -404,11 +406,6 @@ function update_do_one($module, $number, $dependency_map, &$context) {
 }
 
 /**
- * @class Exception class used to throw error if a module update fails.
- */
-class DrupalUpdateException extends Exception { }
-
-/**
  * Start the database update batch process.
  *
  * @param $start
diff --git a/core/lib/Drupal/Core/Utility/UpdateException.php b/core/lib/Drupal/Core/Utility/UpdateException.php
new file mode 100644
index 0000000..d86992c
--- /dev/null
+++ b/core/lib/Drupal/Core/Utility/UpdateException.php
@@ -0,0 +1,13 @@
+<?php
+
+/*
+ * @file
+ * Definition of Drupal\Core\Utility\UpdateException.
+ */
+
+namespace Drupal\Core\Utility;
+
+/**
+ * Exception class used to throw error if a module update fails.
+ */
+class UpdateException extends Exception { }
diff --git a/core/modules/system/system.api.php b/core/modules/system/system.api.php
index 7424015..c8a9c86 100644
--- a/core/modules/system/system.api.php
+++ b/core/modules/system/system.api.php
@@ -5,6 +5,8 @@
  * Hooks provided by Drupal core and the System module.
  */
 
+use Drupal\Core\Utility\UpdateException;
+
 /**
  * @addtogroup hooks
  * @{
@@ -2967,10 +2969,11 @@ function hook_install() {
  * @param $sandbox
  *   Stores information for multipass updates. See above for more information.
  *
  * @throws DrupalUpdateException, PDOException
  *   In case of error, update hooks should throw an instance of DrupalUpdateException
  *   with a meaningful message for the user. If a database query fails for whatever
  *   reason, it will throw a PDOException.
  *
  * @return
  *   Optionally update hooks may return a translated string that will be displayed
@@ -3021,7 +3024,7 @@ function hook_update_N(&$sandbox) {
   return t('The update did what it was supposed to do.');
 
   // In case of an error, simply throw an exception with an error message.
-  throw new DrupalUpdateException('Something went wrong; here is what you should do.');
+  throw new UpdateException('Something went wrong; here is what you should do.');
 }
 
 /**
@@ -2967,10 +2969,11 @@ function hook_install() {
  *   Stores information for multipass updates. See above for more information.
  *
- * @throws DrupalUpdateException, PDOException
- *   In case of error, update hooks should throw an instance of DrupalUpdateException
- *   with a meaningful message for the user. If a database query fails for whatever
- *   reason, it will throw a PDOException.
+ * @throws Drupal\Core\Utility\UpdateException, PDOException
+ *   In case of error, update hooks should throw an instance of
+ *   Drupal\Core\Utility\UpdateException with a meaningful message for the user.
+ *   If a database query fails for whatever reason, it will throw a
+ *   PDOException.
  *
  * @return
